==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_62.js <==
var searchData=
[
  ['base_5fcont_5fget',['BASE_CONT_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#aae72e041820aab3cb0c665bb50d9c031',1,'plplot::core::plplotjavacJNI']]],
  ['bhunt_5fsearch',['bhunt_search',['../qsastime_8c.html#ac4ecc71b746168056d0c2ac611504452',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c'],['../qsastimeP_8h.html#a4023570fb0c462f766569147984ea58b',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c']]],
  ['big_5frecl',['big_recl',['../plshade_8c.html#af0b5c0ec2e072e4bdca795e20a09f7d7',1,'plshade.c']]],
  ['bin',['bin',['../classplstream.html#aad778bc5fa73b64be84fa815ef5e755c',1,'plstream::bin()'],['../classplplot_1_1core_1_1PLStream.html#ac37bea0bb8755b68860d02de1d506d73',1,'plplot.core.PLStream.bin()']]],
  ['bisect',['bisect',['../plshade_8c.html#ad9b7f684c20f74b1eb2211f2237a079b',1,'plshade.c']]],
  ['blit_5fto_5fx',['blit_to_x',['../cairo_8c.html#ac5666021a1bc9cd52badd9120ad66f5c',1,'cairo.c']]],
  ['blitrectangle',['BlitRectangle',['../classwxPLDevBase.html#ac2a624975d558ef9f33b3ce9d6962ac2',1,'wxPLDevBase::BlitRectangle()'],['../classwxPLDevDC.html#af3e2b48fe4e991d71ef8bb0adafe096c',1,'wxPLDevDC::BlitRectangle()']]],
  ['bop',['bop',['../classplstream.html#ae06d098b31cd579cd41d81f5db1c6be8',1,'plstream::bop()'],['../classplplot_1_1core_1_1PLStream.html#a613c97d564bc4bf11b8103a130ced6e7',1,'plplot.core.PLStream.bop()']]],
  ['box',['box',['../classplstream.html#ac61565fc7b11af20d18b49a085af1071',1,'plstream::box()'],['../classplplot_1_1core_1_1PLStream.html#aec8f28c87f2fd22630cd278c33d93810',1,'plplot.core.PLStream.box()']]],
  ['box3',['box3',['../classplstream.html#a98036fa884d2a01a13ba3b409582827d',1,'plstream::box3()'],['../classplplot_1_1core_1_1PLStream.html#a48bf601858b4a737533a21a498e9656f',1,'plplot.core.PLStream.box3()']]],
  ['breakdownmjd',['breakDownMJD',['../qsastime_8c.html#a7e006df720f4dad12fc0f64f9e2e4e84',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5fb852c7385522e8c4cd10f1b05a3bdd',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
  ['btime',['btime',['../classplstream.html#a8d930554eddade61d8cee0fa029bae9f',1,'plstream::btime()'],['../classplplot_1_1core_1_1PLStream.html#adf4d352cce393fb6cbbb77a1e80d9eaf',1,'plplot.core.PLStream.btime()']]],
  ['btimeqsas',['btimeqsas',['../qsastime_8c.html#a7305589289ca3100d933219768b6eb95',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#ac57c643f9118449188d38b77604df2a0',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c']]],
  ['build_5fmenu_5fbar',['build_menu_bar',['../namespacePlframe.html#ad9a8301eba2d43f9a2a06ae9929ad8cf',1,'Plframe']]],
  ['buildlist',['buildlist',['../plfill_8c.html#a10842154848df7e58bfe1b0698082edd',1,'buildlist(PLINT, PLINT, PLINT, PLINT, PLINT, PLINT, PLINT):&#160;plfill.c'],['../plfill_8c.html#a1db96be13602134cdb90815f0f14aae0',1,'buildlist(PLINT xp1, PLINT yp1, PLINT xp2, PLINT yp2, PLINT PL_UNUSED(xp3), PLINT yp3, PLINT dinc):&#160;plfill.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_62.js <==
var searchData=
[
  ['base_5fcont_5fget',['BASE_CONT_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#aae72e041820aab3cb0c665bb50d9c031',1,'plplot::core::plplotjavacJNI']]],
  ['beginpage',['BeginPage',['../classwxPLDevice.html#a908760e63e954c0b5aadc093c8f9e9ef',1,'wxPLDevice']]],
  ['bhunt_5fsearch',['bhunt_search',['../qsastime_8c.html#ac4ecc71b746168056d0c2ac611504452',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c'],['../qsastimeP_8h.html#a4023570fb0c462f766569147984ea58b',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c']]],
  ['big_5frecl',['big_recl',['../plshade_8c.html#af0b5c0ec2e072e4bdca795e20a09f7d7',1,'plshade.c']]],
  ['bin',['bin',['../classplstream.html#aad778bc5fa73b64be84fa815ef5e755c',1,'plstream::bin()'],['../classplplot_1_1core_1_1PLStream.html#ac37bea0bb8755b68860d02de1d506d73',1,'plplot.core.PLStream.bin()']]],
  ['bisect',['bisect',['../plshade_8c.html#ad9b7f684c20f74b1eb2211f2237a079b',1,'plshade.c']]],
  ['blit_5fto_5fx',['blit_to_x',['../cairo_8c.html#ac5666021a1bc9cd52badd9120ad66f5c',1,'cairo.c']]],
  ['bop',['bop',['../classplstream.html#ae06d098b31cd579cd41d81f5db1c6be8',1,'plstream::bop()'],['../classplplot_1_1core_1_1PLStream.html#a613c97d564bc4bf11b8103a130ced6e7',1,'plplot.core.PLStream.bop()']]],
  ['box',['box',['../classplstream.html#ac61565fc7b11af20d18b49a085af1071',1,'plstream::box()'],['../classplplot_1_1core_1_1PLStream.html#aec8f28c87f2fd22630cd278c33d93810',1,'plplot.core.PLStream.box()']]],
  ['box3',['box3',['../classplstream.html#a98036fa884d2a01a13ba3b409582827d',1,'plstream::box3()'],['../classplplot_1_1core_1_1PLStream.html#a48bf601858b4a737533a21a498e9656f',1,'plplot.core.PLStream.box3()']]],
  ['breakdownmjd',['breakDownMJD',['../qsastime_8c.html#a7e006df720f4dad12fc0f64f9e2e4e84',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5fb852c7385522e8c4cd10f1b05a3bdd',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
  ['btime',['btime',['../classplstream.html#a8d930554eddade61d8cee0fa029bae9f',1,'plstream::btime()'],['../classplplot_1_1core_1_1PLStream.html#adf4d352cce393fb6cbbb77a1e80d9eaf',1,'plplot.core.PLStream.btime()']]],
  ['btimeqsas',['btimeqsas',['../qsastime_8c.html#a7305589289ca3100d933219768b6eb95',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#ac57c643f9118449188d38b77604df2a0',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c']]],
  ['build_5fmenu_5fbar',['build_menu_bar',['../namespacePlframe.html#ad9a8301eba2d43f9a2a06ae9929ad8cf',1,'Plframe']]],
  ['buildlist',['buildlist',['../plfill_8c.html#a10842154848df7e58bfe1b0698082edd',1,'buildlist(PLINT, PLINT, PLINT, PLINT, PLINT, PLINT, PLINT):&#160;plfill.c'],['../plfill_8c.html#a1db96be13602134cdb90815f0f14aae0',1,'buildlist(PLINT xp1, PLINT yp1, PLINT xp2, PLINT yp2, PLINT PL_UNUSED(xp3), PLINT yp3, PLINT dinc):&#160;plfill.c']]]
];
